# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# CMake-builds go out-of-tree.
%global _cmake_build_subdir build-%{_target_platform}

Name:		libyui-ncurses
Version:	2.48.3
Release:	7%{?dist}
Summary:	Character Based User Interface for libyui

License:	LGPLv2 or LGPLv3
URL:		https://github.com/libyui/%{name}
Source0:	%{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:		%{url}/commit/6444e043b58bf7703e4fc9035f380f3817207525.patch#/fix_build_with_new_ncurses.patch

BuildRequires:  gcc-c++
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	libyui-devel
BuildRequires:	ncurses-devel

Supplements:	(libyui%{?_isa} and ncurses-libs%{?_isa})

%description
This package contains the character based (ncurses) user interface
component for libyui.


%package devel
Summary:	Files needed for developing with %{name}

Requires:	libyui-devel%{?_isa}
Requires:	%{name}%{?_isa}			== %{version}-%{release}
Requires:	ncurses-devel%{?_isa}

%description devel
libyui can be used independently of YaST for generic (C++)
applications and has very few dependencies.

You do NOT need this package for developing with libyui.
Using libyui-devel is sufficient for such purpose.  This
package is only needed when you want to develop an extension
for %{name} which is not covered within the UI-plugin.


%package doc
Summary:	Documentation files for %{name}
BuildArch:	noarch

BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	hardlink

%description doc
This package includes the developer's documentation as HTML
for %{name}.


%prep
%autosetup -p 1
./bootstrap.sh


%build
%{__mkdir} -p %{_cmake_build_subdir}
pushd %{_cmake_build_subdir}
%cmake							\
	-DYPREFIX=%{_prefix}				\
	-DLIB_DIR=%{_libdir}				\
	-DCMAKE_BUILD_TYPE=RELEASE			\
	-DRESPECT_FLAGS=ON				\
	-DSKIP_LATEX=ON					\
	..

%make_build
%make_build docs
popd


%install
pushd %{_cmake_build_subdir}
%{__mkdir} -p	%{buildroot}%{_libdir}/yui		\
		%{buildroot}%{_datadir}/%{name}/theme

%make_install

# Delete obsolete files.
%{__rm} -rf	%{buildroot}%{_defaultdocdir}		\
		doc/html/*.m*

# Install documentation.
%{__mkdir} -p	%{buildroot}%{?_pkgdocdir}
%{__cp} -a	../package/%{name}.changes doc/html/	\
		%{buildroot}%{?_pkgdocdir}

# Hard-link documentation.
%{_sbindir}/hardlink -cv %{buildroot}%{?_pkgdocdir}/html
popd


%files
%doc %dir %{?_pkgdocdir}
%license COPYING*
%{_bindir}/libyui-terminal
%{_libdir}/yui/%{name}.so.%{_libyui_major_so_ver}*


%files devel
%doc %{?_pkgdocdir}/%{name}.changes
%{_datadir}/libyui/*
%{_includedir}/yui/*
%{_libdir}/yui/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}


%files doc
# Pickup license-files from main-pkg's license-dir
# If there's no license-dir they are picked up by %%doc previously
%{?_licensedir:%license %{_datadir}/licenses/%{name}*}
%doc %{?_pkgdocdir}


%changelog
* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.48.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.48.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Aug 13 2018 Leigh Scott <leigh123linux@googlemail.com> - 2.48.3-5
- Fix build with new ncurses

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.48.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.48.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.3-2
- Dependency on cmake-filesystem is autogenerated now
- Skip building of LaTeX-docs

* Mon Jul 31 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.3-1
- New upstream release

* Sun Jul 30 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-8
- Require cmake-filesystem

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.48.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 03 2017 Jonathan Wakely <jwakely@redhat.com> - 2.48.1-6
- Rebuilt for Boost 1.64

* Sat Apr 29 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-5
- Rebuilt for bootstrapping new arch: s390x

* Fri Apr 14 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-4
- Fix hardlinking of html-docs

* Thu Apr 13 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-3
- Rebuilt for libyui.so.8

* Wed Apr 12 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-2
- Spec-file cosmetics

* Tue Apr 11 2017 Björn Esser <besser82@fedoraproject.org> - 2.48.1-1
- New upstream release

* Mon Apr 10 2017 Björn Esser <besser82@fedoraproject.org> - 2.47.7-5
- Use rich-dependencies instead of virtual provides
- Get major so-ver from macro

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.47.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 2.47.7-3
- Rebuilt for Boost 1.63

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 2.47.7-2
- Rebuilt for Boost 1.63

* Fri Nov 18 2016 Christian Dersch <lupinix@mailbox.org> - 2.47.7-1
- new version

* Tue Mar 29 2016 Björn Esser <fedora@besser82.io> - 2.47.6-1
- new upstream release
- handle %%license and %%doc properly

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.47.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 2.47.2-2
- Rebuilt for Boost 1.59

* Thu Aug 27 2015 Björn Esser <bjoern.esser@gmail.com> - 2.47.2-1
- new upstream release
- added %%{_bindir}/libyui-terminal

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.7-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 04 2015 Kalev Lember <kalevlember@gmail.com> - 2.46.7-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-3
- rebuilt for libyui-3.1.5, again

* Mon Feb 02 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-2
- Rebuild for boost 1.57.0

* Tue Jan 20 2015 Björn Esser <bjoern.esser@gmail.com> - 2.46.7-1
- new upstream release (#1183541)
- rebuilt for libyui-3.1.5
- keep doc-files in unfied %%{_pkgdocdir}
- small improvements to spec-file

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.46.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 24 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.4-2
- no need to provide `%%{name}-devel-common`

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.46.4-1
- new upstream release

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-3
- Rebuild for boost 1.55.0

* Tue Mar 18 2014 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-2
- rebuilt for libyui-3.0.13
- remove build of pdf-autodocs
- remove the devel-common subpkg
- minor improvents on spec

* Fri Aug 30 2013 Björn Esser <bjoern.esser@gmail.com> - 2.44.1-1
- new upstream version
- restructured spec to match with libyui

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.43.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu May 16 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-3
- changed Provides: `yui_ui =` from `version` to `major_so_ver`
- install lib*.so.`major_so_ver`* in main-pkg not lib*.so.*
- add `-DRESPECT_FLAGS=ON`, will be honored by libyui <= 3.0.5
- removed macros from changelog

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-2
- -devel pkg should have Requires: ncurses-devel instead of
  Requires: ncurses

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.9-1
- new upstream version
- adjusted libyui-devel min-version
- added needed bootstrap to prep

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.8-2
- fixup as suggested in https://bugzilla.redhat.com/show_bug.cgi?id=960199#c3
- exchanged {parname} with {libname}

* Mon May 13 2013 Björn Esser <bjoern.esser@gmail.com> - 2.43.8-1
- Initial RPM release.
